@@ -6,11 +6,7 @@ try:
 except ImportError:
     raise 'pip install ninjatools[memory] or ninjatools[all]  to use image functions!'
 
-from ninja_tools.utils import Utilities
-
-Utilities.try_import('ReadWriteMemory', 'git+https://github.com/vsantiago113/ReadWriteMemory')
-
-from ReadWriteMemory import ReadWriteMemory
+from ninja_tools.ReadWriteMemory import ReadWriteMemory
 
 
 class Parser:
@@ -28,6 +24,10 @@ class Parser:
         self.base_address = pymem.process.module_from_name(
             self.pm.process_handle, self.process_name).lpBaseOfDll
 
+    # Misc
+    def get_address(self, process):  # Gets the base address of a process (example: gepard.dll)
+        return pymem.process.module_from_name(self.pm.process_handle, process).lpBaseOfDll
+
     # Readers
     def read(self, address):
         # return self.process.read(address)
