@@ -2,9 +2,9 @@ import ctypes
 import subprocess
 import sys
 from datetime import datetime
-from math import sqrt
 from time import perf_counter, sleep
 
+import numpy as np
 import pkg_resources
 import psutil
 import pyperclip
@@ -57,7 +57,9 @@ class Utilities:
 
     @staticmethod
     def get_distance(p0, p1):
-        return sqrt((p0[0] - p1[0]) ** 2 + (p0[1] - p1[1]) ** 2)
+        p0 = np.array(p0)
+        p1 = np.array(p1)
+        return np.linalg.norm(p0 - p1)
 
     def get_distance_int(self, p0, p1):
         return int(self.get_distance(p0, p1))
@@ -139,17 +141,58 @@ class Utilities:
         rect = self._get_rect("CLIENT", handle)
         return BBOX(rect) if bbox else rect
 
+    # Get all pid of process with same names
+    @staticmethod
+    def get_pids_from_process_name(process_name):
+        return [_.pid for _ in psutil.process_iter() if _.name() == process_name]
+
+    # # Get all pid of process with same names using window name
+    @staticmethod
+    def get_pids_from_window_title(window_title):
+        def callback(hwnd, hwnd_list_):
+            if win32gui.IsWindowVisible(hwnd) and win32gui.GetWindowText(hwnd) == window_title:
+                _, found_pid = win32process.GetWindowThreadProcessId(hwnd)
+                hwnd_list_.append(found_pid)
+            return True
+
+        hwnd_list = []
+        win32gui.EnumWindows(callback, hwnd_list)
+        return hwnd_list
+
     ##########################
     # Utility Functions
     ##########################
     @staticmethod
     def find(input_, string, options=any, contains=True):
+        """
+        A function that checks if a given string contains or does not contain one or more items from a list or a
+        single item.
+        :param input_: A list of items or a single item
+        :param string: The string to be checked
+        :param options: A function that defines how to check the items in the list (default: any)
+        :param contains: A flag to indicate whether to check if the items are in the string or not (default: True)
+        :return: Boolean value indicating whether the string contains or does not contain the items
+
+        Example:
+        # Check if the string "Hello World" contains any of the items in the list ["Hello", "Goodbye"]
+        result = find(["Hello", "Goodbye"], "Hello World")
+        print(result) # True
+
+        # Check if the string "Hello World" contains all of the items in the list ["Hello", "Goodbye"]
+        result = find(["Hello", "Goodbye"], "Hello World", all)
+        print(result) # False
+        """
+        # Check if input_ is a list
         if isinstance(input_, list):
+            # Check if we are checking if the string contains the items or not
             if contains:
+                # Use the options function to check if any or all of the items are in the string
                 return options(item in string for item in input_)
             else:
+                # Use the options function to check if any or all of the items are not in the string
                 return options(item not in string for item in input_)
         else:
+            # If input_ is not a list, check if it's in the string or not
             if contains:
                 return string in input_
             else:
